@@ -1,7 +1,7 @@
 # pylint: disable=invalid-name
 from enum import Enum
 from robot.libraries.BuiltIn import BuiltIn
-from FlaUILibrary import version, clr
+from FlaUILibrary import version, pythonnetwrapper
 from FlaUILibrary.keywords import (ApplicationKeywords,
                                    CheckBoxKeywords,
                                    ComboBoxKeywords,
@@ -15,6 +15,7 @@ from FlaUILibrary.keywords import (ApplicationKeywords,
                                    GridKeywords,
                                    RadioButtonKeywords,
                                    ListBoxKeywords,
+                                   TreeKeywords,
                                    TabKeywords)
 from FlaUILibrary.robotframework import DynamicCore, robotlog
 from FlaUILibrary.flaui import (UIA2, UIA3)
@@ -83,14 +84,16 @@ class FlaUILibrary(DynamicCore):
         WINDOW = "Window"
         RADIOBUTTON = "Radiobutton"
         LISTBOX = "Listbox"
+        TREE = "Tree"
         TAB = "Tab"
 
-    def __init__(self, uia='UIA3', screenshot_on_failure='True', screenshot_dir=None):
+    def __init__(self, uia='UIA3', screenshot_on_failure='True', screenshot_dir=None, timeout=1000):
         """FlaUiLibrary can be imported by following optional arguments:
 
         ``uia`` Microsoft UI-Automation framework to use. UIA2 or UIA3
         ``screenshot_on_failure`` indicator to disable or enable screenshot feature.
         ``screenshot_dir`` is the directory where screenshots are saved.
+        ``timeout`` maximum amount of waiting time in ms for an element find action. Default value is 1000ms.
 
         If the given directory does not already exist, it will be created when the first screenshot is taken.
         If the argument is not given, the default location for screenshots is the output directory of the Robot run,
@@ -99,10 +102,19 @@ class FlaUILibrary(DynamicCore):
         # FlaUI init
         self.mode = FlaUILibrary.RobotMode.TEST_NOT_RUNNING
         self.builtin = BuiltIn()
+
+        try:
+            if timeout == "None":
+                timeout = 0
+            elif int(timeout) <= 0:
+                timeout = 0
+        except ValueError:
+            timeout = 1000
+
         if uia == "UIA2":
-            self.module = UIA2()
+            self.module = UIA2(timeout)
         else:
-            self.module = UIA3()
+            self.module = UIA3(timeout)
 
         self.screenshots = Screenshot(screenshot_dir, screenshot_on_failure == 'True')
 
@@ -120,6 +132,7 @@ class FlaUILibrary(DynamicCore):
             FlaUILibrary.KeywordModules.WINDOW: WindowKeywords(self.module),
             FlaUILibrary.KeywordModules.RADIOBUTTON: RadioButtonKeywords(self.module),
             FlaUILibrary.KeywordModules.LISTBOX: ListBoxKeywords(self.module),
+            FlaUILibrary.KeywordModules.TREE: TreeKeywords(self.module),
             FlaUILibrary.KeywordModules.TAB: TabKeywords(self.module),
         }
 
